@@ -390,6 +390,28 @@ impl Tera {
         }
     }
 
+    /// Returns an iterator over the names of all registered templates in an
+    /// unspecified order.
+    ///
+    /// # Example
+    ///
+    /// ```rust
+    /// use tera::Tera;
+    ///
+    /// let mut tera = Tera::default();
+    /// tera.add_raw_template("foo", "{{ hello }}");
+    /// tera.add_raw_template("another-one.html", "contents go here");
+    ///
+    /// let names: Vec<_> = tera.get_template_names().collect();
+    /// assert_eq!(names.len(), 2);
+    /// assert!(names.contains(&"foo"));
+    /// assert!(names.contains(&"another-one.html"));
+    /// ```
+    #[inline]
+    pub fn get_template_names(&self) -> impl Iterator<Item = &str> {
+        self.templates.keys().map(|s| s.as_str())
+    }
+
     /// Add a single template to the Tera instance
     ///
     /// This will error if the inheritance chain can't be built, such as adding a child
@@ -550,7 +572,6 @@ impl Tera {
         self.register_filter("trim_end", string::trim_end);
         self.register_filter("trim_start_matches", string::trim_start_matches);
         self.register_filter("trim_end_matches", string::trim_end_matches);
-        #[cfg(feature = "builtins")]
         self.register_filter("truncate", string::truncate);
         self.register_filter("wordcount", string::wordcount);
         self.register_filter("replace", string::replace);
